//  dcounts-js.js EY edited for gov uk framework

(function (root, factory) {
  if (typeof define === 'function' && define.amd) {
    define('dCounts', factory)
  } else if (typeof exports === 'object' && module.exports) {
    module.exports = factory
  } else {
    root.dCounts = factory
  }
}(this, function dCounts(selector, limit=150) {
  if (typeof selector !== 'string' && typeof limit !== 'number') {
    return
  }
  const el = document.getElementById(selector)

  const div = `<div id="counters-${selector}" class="eyTextAreaMaxCharacters">You have ${limit} characters remaining</div>`
 
  const init = () => {
    if (el === null) {
      throw new Error(`Something's wrong with your selector`)
    }
    createDiv()
    el.addEventListener('keyup', counters, false)
  }

  const createDiv = () => el.insertAdjacentHTML('afterend', div)

  const counters = () => {
    let total = limit
    let typedCharacters = el.value.length
    let count = document.getElementById(`counters-${selector}`)
	var remaindingCharacters = limit - typedCharacters
	var overCharacters = typedCharacters - limit
    count.innerHTML = `You have ${remaindingCharacters} characters remaining`

    if (typedCharacters >= total + 1) {
	  count.classList.add("eyTextAreaMaxCharacters_Alert")
      count.innerHTML = `You have ${overCharacters} characters too many`
    } else {
		count.classList.remove("eyTextAreaMaxCharacters_Alert")
	}
  }
  init()
}))

//Hide all hidden fields on review page
document.addEventListener('DOMContentLoaded', function() {	
	
	setTimeout(function() {
		
		//Hide all picklists with two items both unchecked
		var AllPicklistsWithinReviewPage = document.getElementsByClassName("ey-entity-form-reviewpage")[0].getElementsByClassName("picklist");

		for (let i = 0; i < AllPicklistsWithinReviewPage.length; i++) {
		  
			var AllInputsWithinPicklist = document.getElementsByClassName("ey-entity-form-reviewpage")[0].getElementsByClassName("picklist")[i].getElementsByTagName('input');
		  
			if (AllInputsWithinPicklist.length == 2 && AllInputsWithinPicklist[0].checked == false && AllInputsWithinPicklist[1].checked == false){
				AllPicklistsWithinReviewPage[i].closest("td").style.display = "none";
			}
		};


		//Hide all with class text-muted
		var AllHiddenFieldsWithinReviewPage = document.getElementsByClassName("ey-entity-form-reviewpage")[0].getElementsByClassName("text-muted");

		for (let i = 0; i < AllHiddenFieldsWithinReviewPage.length; i++) {
		  AllHiddenFieldsWithinReviewPage[i].closest("td").style.display = "none";
		};
		
		// Show Notes
		document.getElementById('notescontrol').closest("td").style.display = "table-cell";	
		
	},500); 
	
}, false);

// Hide Back Button and add Back Link
document.addEventListener('DOMContentLoaded', function() {	

	var PreviousButton = document.getElementById("PreviousButton");
	var PreviousButtonOnClickEvent = PreviousButton.onclick;
	PreviousButtonOnClickEvent = String(PreviousButtonOnClickEvent).split("{").pop();
	PreviousButtonOnClickEvent = PreviousButtonOnClickEvent.slice(0, -1);
	var WebFormPanel = document.getElementById("WebFormPanel");


	let GovukBackLink = document.createElement("a");
	GovukBackLink.href = "#";
	GovukBackLink.setAttribute('onclick', PreviousButtonOnClickEvent);
	GovukBackLink.innerHTML = "Back";
	GovukBackLink.classList.add('govuk-back-link');
	GovukBackLink.setAttribute('id', 'prev-button-replacement');

	let GovukBackLinkContainer = document.createElement("div");
	GovukBackLinkContainer.prepend(GovukBackLink);
	GovukBackLinkContainer.setAttribute('id', 'prev-button-replacement-container');

	if (WebFormPanel.contains(PreviousButton)) {
		
		WebFormPanel.parentNode.parentNode.prepend(GovukBackLinkContainer);	

		PreviousButton.parentNode.style.display = "none";
		
		var PageContainer = document.getElementsByClassName("columnBlockLayout");
		var PageBackLink = document.getElementById("page-back-link");

		if (PageContainer[0].contains(PageBackLink)) {
			
			PageBackLink.style.display = "none";

		}
	}

}, false);

// Hide Back Button on Form Success 
document.addEventListener('DOMContentLoaded', function() {	
	
	var WebFormControl = document.querySelectorAll('[id^="WebFormControl"]')[0];
	var MessagePanel = document.getElementById("MessagePanel");
	var PageBackLinkContainer = document.getElementById("page-back-link-container");

	if (WebFormControl.contains(MessagePanel)) {
			PageBackLinkContainer.style.display = "none";
	}	

}, false);

// Form Session Error Message

document.addEventListener('DOMContentLoaded', function() {	

	var WebFormControl = document.querySelectorAll('[id^="WebFormControl"]')[0];
	var MessagePanel = document.getElementById("MessagePanel");
	var WebFormPanel = document.getElementById("WebFormPanel");
	let FormSessionErrorMessage = document.createElement("div");
	FormSessionErrorMessage.setAttribute('id', 'form-session-error-message');
	FormSessionErrorMessage.innerHTML = "<p>Your form session has expired and your details have been purged as a privacy and security precaution.</p><p>If you wish to restart your form submission please <a href=\"/\">return to our contact page</a>.</p>";
			
	if (!WebFormControl.contains(MessagePanel) && !WebFormControl.contains(WebFormPanel)) {			
			WebFormControl.prepend(FormSessionErrorMessage);
			document.getElementById("page-back-link-container").style.display = "none";
	}
		
}, false);

// Charity Lookup
document.addEventListener('DOMContentLoaded', () => {
  const searchInput = document.getElementById('ey_organisationcharityuserinput'); 
  const resultdiv = `<br> <br><div id="search-results" class="search-results"></div>`;  
  searchInput.insertAdjacentHTML('afterend', resultdiv) ; 
  const searchResults = document.getElementById('search-results');
  const nextButton = document.getElementById('NextButton');
  var searchValue = "";
  searchInput.setAttribute("autocomplete","off");

  searchInput.addEventListener('keyup', async (event) => {
   // const query = event.target.value;
    nextButton.setAttribute("disabled","disabled");
    setTimeout(async function(){
      const query = $("#ey_organisationcharityuserinput").val();
      if (query.length > 0) {
        const records = await fetchRecords(query);
        displayRecords(records);
      } else {
        searchResults.style.display = 'none';
      }
    },2000);
  });

  searchInput.addEventListener('keypress', async (event) => {
    if(event.key === 'Enter')
    {
      if(searchValue === "")
      {
        event.preventDefault();
        return;
      }
      else {
        if (searchInput.value === searchValue)
        {
          event.preventDefault();
          nextButton.click();
        }
        else
        {
          event.preventDefault();
        }
      }
    }
  });

  async function fetchRecords(query) {
   const orgUrl = "https://" + window.location.host;
  
   const fetchUrl = `${orgUrl}/_api/accounts?$select=name,py3_charityorganisationnameandnumber&$filter=(contains(py3_charityorganisationnameandnumber, '${query}') and statecode eq 0) and py3_registeredidnumber ne null and py3_registeredidnumber ne '0'&$orderby=py3_charityorganisationnameandnumber asc&$top=10`;
  
    try {
      const response = await fetch(fetchUrl, {
        method: "GET",
        headers: {
            "OData-MaxVersion": "4.0",
            "OData-Version": "4.0",
            "Accept": "application/json",
            "Content-Type": "application/json; charset=utf-8",
            "Prefer": "odata.include-annotations=\"*\""
        },
      });

      const data = await response.json();
      return data.value;
    } catch (error) {
      console.error('Error fetching records:', error);
      return [];
    }
  }

  function displayRecords(records) {
    searchResults.innerHTML = '';
    const nextButton = document.getElementById('NextButton');
    if (records.length > 0) {
      records.forEach(record => {
          const recordElement = document.createElement('div');
          recordElement.textContent = record.py3_charityorganisationnameandnumber;  
          recordElement.addEventListener('click', () => {
            searchInput.value = record.py3_charityorganisationnameandnumber;
            searchValue = record.py3_charityorganisationnameandnumber;
            searchResults.style.display = 'none';
            nextButton.removeAttribute("disabled");
          });

        searchResults.appendChild(recordElement);
      });

      searchResults.style.display = 'block';
    } else {
      searchResults.style.display = 'none';
    }
  }
});